Registry

Struct Registry 

pub struct Registry<T> { /* private fields */ }
Available on crate feature azure_policy only.
Generic thread-safe registry for items of type T using DashMap.

This template can be used to create registries for any type T. It provides thread-safe storage and retrieval operations with customizable registry names.

Implementations

Source

impl<T> Registry<T>

pub fn new(registry_name: impl Into<Rc<str>>) -> Self

Create a new, empty registry with a given name.

pub fn name(&self) -> &str

Get the name of this registry.

pub fn register( &self, name: impl Into<Rc<str>>, item: Rc<T>, ) -> Result<(), RegistryError>

Register an item with a given name. Returns Err if name already exists.

pub fn get(&self, name: &str) -> Option<Rc<T>>

Retrieve an item by name, if it exists.

pub fn remove(&self, name: &str) -> Option<Rc<T>>

Remove an item by name. Returns the removed item if it existed.

pub fn list_names(&self) -> Vec<Rc<str>>

List all registered item names.

pub fn contains(&self, name: &str) -> bool

Check if an item with the given name exists.

pub fn len(&self) -> usize

Get the number of registered items.

pub fn is_empty(&self) -> bool

Check if the registry is empty.

pub fn clear(&self)

Clear all items from the registry.

pub fn iter(&self) -> impl Iterator<Item = (Rc<str>, Rc<T>)> + '_

Get an iterator over all entries in the registry. Returns an iterator of (name, item) pairs.

pub fn list_items(&self) -> Vec<Rc<T>>

Get all registered items as a vector.

pub fn try_register( &self, name: impl Into<Rc<str>>, item: Rc<T>, ) -> Result<bool, RegistryError>

Try to register an item, but don’t fail if the name already exists. Returns Ok(true) if the item was registered, Ok(false) if the name already exists.